import { DlzAccountNetwork, NetworkEntityVpc } from './dlz-account-network';
import { NetworkAddress } from './network-address';
import { DLzAccount } from '../../data-landing-zone-types';
type MatchOnAddress = 'account' | 'region' | 'vpc' | 'routeTable' | 'subnet' | undefined;
export declare class DlzAccountNetworks {
    private dlzAccountNetworks;
    add(dlzAccount: DLzAccount, networkEntityVpc: NetworkEntityVpc): void;
    private vpcExists;
    /**
     * Get NetworkEntities for the given `networkAddress` and match on the given `matchOnAddress`. For example, if the
     * `networkAddress` is a routeTable address and `matchOnAddress` has a value of `vpc` then it will return all
     * NetworkEntities that have the same VPC as the `networkAddress`. Or, if the `matchOnAddress` has a value of
     * `region` then it will return all NetworkEntities that have the same VPC region as the `networkAddress`.
     *
     * If the `matchOnAddress` is `account` then the complete NetworkEntity will be returned.
     * Else, if `matchOnAddress` is `region`, `vpc`, `routeTable` or `subnet` then a partial NetworkEntity will be returned.
     * The `vpcs` `routeTables` and `subnets` will be filtered to only include those that match the `networkAddress`. A value of
     * `undefined` will automatically detect the level of the `networkAddress` and use that as the `matchOnAddress`.
     *
     * Example:
     *
     * Given we have these NetworkEntity[]:
     * 1. project-1-develop.us-east-1.default.private
     * 2. project-1-develop.eu-west-1.default.private
     * 3. project-1-production.eu-west-1.default.private
     *
     * - If the `networkAddress` has a `routeTable` address of: `project-1-develop.us-east-1.default.private` and the
     *   `matchOnAddress` value is **`routeTable`**. Then it will only match the **first** entry of
     *   `project-1-develop.us-east-1.default.private` and return a partial NetworkEntity with the VPC, and only
     *   the routeTables and subnets that have the same routeTable address.
     *
     * - If the `networkAddress` has the same `routeTable` address of: `project-1-develop.us-east-1.default.private` and the
     *   `matchOnAddress` value is changed to **`vpc`**. Then it will match the **first** and **second** entries
     *    and return the complete NetworkEntity for each.
     *
     * @param networkAddress
     * @param matchOnAddress
     */
    getEntitiesForAddress(networkAddress: NetworkAddress, matchOnAddress?: MatchOnAddress): DlzAccountNetwork[] | undefined;
}
export {};
