import { BudgetSubscribers, DlzControlTowerStandardControls, IamIdentityCenterPermissionSetProps } from './constructs/';
import { DlzBudgetProps } from './constructs/dlz-budget';
import { DlzVpcProps } from './constructs/dlz-vpc/dlz-vpc';
import { DlzTag } from './constructs/organization-policies/tag-policy';
import { DataLandingZoneProps, Region } from './data-landing-zone-types';
export declare enum IamIdentityAccounts {
    ROOT = "dlz:root",
    SECURITY_LOG = "dlz:security:log",
    SECURITY_AUDIT = "dlz:security:audit"
}
export declare enum IamIdentityPermissionSets {
    ADMIN = "dlz:adminaccess",
    READ_ONLY = "dlz:readonlyaccess",
    CATALOG = "dlz:catalogaccess"
}
export declare class Defaults {
    /** *
     * List of services that are denied in the organization
     */
    static denyServiceList(): string[];
    /**
     * Creates a VPC configuration with 2 route tables, one used as public and the other private, each with 3 subnets.
     * Each subnet has a /19 CIDR block. The VPC CIDR is `10.${thirdOctetMask}.0.0/16`
     * There will be remaining space:
     *   - 10.x.192.0/19
     *   - 10.x.224.0/19
     * @param thirdOctetMask the third octet of the VPC CIDR
     * @param region the region where the VPC will be created
     * @returns a VPC configuration
     */
    static vpcClassB3Private3Public(thirdOctetMask: number, region: Region): DlzVpcProps;
    /**
     * Provides the AWS managed policy `AdministratorAccess` and `ReadOnlyAccess` as permission sets
     */
    static iamIdentityCenterPermissionSets(): IamIdentityCenterPermissionSetProps[];
    /** *
     * Mandatory tags for the organization
     */
    static mandatoryTags(props: DataLandingZoneProps): DlzTag[];
    /**
     * Control Tower Controls applied to all the OUs in the organization
     */
    static rootControls(): DlzControlTowerStandardControls[];
    /**
     * Budgets for the organization
     * @param orgTotal Total budget for the organization in USD
     * @param infraDlz Budget for this DLZ project identified by tags Owner=infra, Project=dlz in USD
     * @param subscribers Subscribers for the budget
     */
    static budgets(orgTotal: number, infraDlz: number, subscribers: BudgetSubscribers): DlzBudgetProps[];
}
/**
 * @internal
 */
export declare class PropsOrDefaults {
    static getDenyServiceList(props: DataLandingZoneProps): string[];
    static getOrganizationTags(props: DataLandingZoneProps): DlzTag[];
    static getRootControls(props: DataLandingZoneProps): DlzControlTowerStandardControls[];
}
