import { AwsSdkSigV4AuthInputConfig, AwsSdkSigV4AuthResolvedConfig, AwsSdkSigV4PreviouslyResolved } from "@aws-sdk/core";
import { HandlerExecutionContext, HttpAuthScheme, HttpAuthSchemeParameters, HttpAuthSchemeParametersProvider, HttpAuthSchemeProvider } from "@smithy/types";
import { CostExplorerClientResolvedConfig } from "../CostExplorerClient";
/**
 * @internal
 */
export interface CostExplorerHttpAuthSchemeParameters extends HttpAuthSchemeParameters {
    region?: string;
}
/**
 * @internal
 */
export interface CostExplorerHttpAuthSchemeParametersProvider extends HttpAuthSchemeParametersProvider<CostExplorerClientResolvedConfig, HandlerExecutionContext, CostExplorerHttpAuthSchemeParameters, object> {
}
/**
 * @internal
 */
export declare const defaultCostExplorerHttpAuthSchemeParametersProvider: (config: CostExplorerClientResolvedConfig, context: HandlerExecutionContext, input: object) => Promise<CostExplorerHttpAuthSchemeParameters>;
/**
 * @internal
 */
export interface CostExplorerHttpAuthSchemeProvider extends HttpAuthSchemeProvider<CostExplorerHttpAuthSchemeParameters> {
}
/**
 * @internal
 */
export declare const defaultCostExplorerHttpAuthSchemeProvider: CostExplorerHttpAuthSchemeProvider;
/**
 * @internal
 */
export interface HttpAuthSchemeInputConfig extends AwsSdkSigV4AuthInputConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    httpAuthSchemes?: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    httpAuthSchemeProvider?: CostExplorerHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export interface HttpAuthSchemeResolvedConfig extends AwsSdkSigV4AuthResolvedConfig {
    /**
     * Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    readonly httpAuthSchemes: HttpAuthScheme[];
    /**
     * Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    readonly httpAuthSchemeProvider: CostExplorerHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export declare const resolveHttpAuthSchemeConfig: <T>(config: T & HttpAuthSchemeInputConfig & AwsSdkSigV4PreviouslyResolved) => T & HttpAuthSchemeResolvedConfig;
